@@ -10,46 +10,47 @@ class StatementParser(object):
     Defines interface for all parser implementation
     """
 
-    dateFormat = "%Y-%m-%d"
+    date_format = "%Y-%m-%d"
+    cur_record = 0
 
     def parse(self):
         """Read and parse statement
 
         Return Statement object
         """
-        reader = self.createReader()
+        reader = self.split_records()
         for line in reader:
-            self.currentLine += 1
+            self.cur_record += 1
             if not line:
                 continue
-            stmtLine = self.parseLine(line)
-            if (stmtLine):
-                self.statement.lines.append(stmtLine)
+            stmt_line = self.parse_record(line)
+            if (stmt_line):
+                self.statement.lines.append(stmt_line)
         return self.statement
 
-    def createReader(self):
+    def split_records(self):
         """Return iterable object consisting of a line per transaction
         """
         raise NotImplementedError
 
-    def parseLine(self, line):
+    def parse_record(self, line):
         """Parse given transaction line and return StatementLine object
         """
         raise NotImplementedError
 
-    def parseValue(self, value, field):
+    def parse_value(self, value, field):
         tp = type(getattr(StatementLine, field))
         if tp == datetime:
-            return self.parseDateTime(value)
+            return self.parse_datetime(value)
         elif tp == float:
-            return self.parseFloat(value)
+            return self.parse_float(value)
         else:
             return value
 
-    def parseDateTime(self, value):
-        return datetime.strptime(value, self.dateFormat)
+    def parse_datetime(self, value):
+        return datetime.strptime(value, self.date_format)
 
-    def parseFloat(self, value):
+    def parse_float(self, value):
         return float(value)
 
 
@@ -62,19 +63,20 @@ class CsvStatementParser(StatementParser):
     # 0-based csv column mapping to StatementLine field
     mappings = {}
 
-    currentLine = 0
-
     def __init__(self, fin):
         self.statement = Statement()
         self.fin = fin
 
-    def createReader(self):
+    def split_records(self):
         return csv.reader(self.fin)
 
-    def parseLine(self, line):
-        stmtLine = StatementLine()
+    def parse_record(self, line):
+        stmt_line = StatementLine()
         for field, col in self.mappings.items():
+            if col >= len(line):
+                raise ValueError("Cannot find column %s in line of %s items " \
+                                 % (col, len(line)))
             rawvalue = line[col]
-            value = self.parseValue(rawvalue, field)
-            setattr(stmtLine, field, value)
-        return stmtLine
+            value = self.parse_value(rawvalue, field)
+            setattr(stmt_line, field, value)
+        return stmt_line
