@@ -3,3 +3,5 @@
 
 from . import dnb
 from . import swedbank
+from . import maxibps
+from . import danske
